Module text

Module text 

Provides the primary text object, Spans, which is a sequence of styled spans, as well as traits providing support for string-like methods on structs.

Structs

Span
A span of text having a single style.
Spans
A string with various styles applied to the span. Styles do not not cascade. Only the most recent style applies to the current character.
Split
A segment of text split on a delimiter. The delimiter and the segment are both included because the delimiter may have a style applied to it.
Tag
A simple format for surrounding text in tags

Enums

Width
An enum representing the unicode width of a (possibly infinte) text object

Traits

BoundedWidth
Support for returing the unicode width of text objects that are finite
Expandable
Expanding regex captures in text objects.
HasWidth
Support for returning the unicode width of a text object
Joinable
Provides functionality for joining text objects together.
Paintable
Provides functionality to display strings with markup.
Pushable
Trait for text objects that can have content pushed into them without changing type.
RawText
Support for converting a text object into a raw, unstyled string
Replaceable
Replacing text in text-like objects.
Sliceable
Provides function for slicing a text object on byte index (like str::get)
Splitable
Text objects that can be split on a delimiter or pattern
WidthSliceable
Provides a function for slicing by grapheme width rather than bytes.